#include <SoftwareSerial.h>
#include <DHT.h>

// Bluetooth setup
SoftwareSerial bt(7, 8);  // RX, TX

// DHT11 setup
#define DHTPIN 4
#define DHTTYPE DHT11
DHT dht(DHTPIN, DHTTYPE);

// LED control pins
const int ledPins[] = {3, 5, 6, 9, 10, 11};
const int numLeds = 6;

void setup() {
  // Initialize serial communications
  Serial.begin(9600);
  bt.begin(9600);

  // Initialize DHT sensor
  dht.begin();
  
  // Initialize LED pins
  for (int i = 0; i < numLeds; i++) {
    pinMode(ledPins[i], OUTPUT);
    digitalWrite(ledPins[i], LOW);  // Start with LEDs off
  }
}

void loop() {
  // Part 1: DHT11 Sensor Reading and Bluetooth Transmission
  static unsigned long lastDHTRead = 0;
  if (millis() - lastDHTRead >= 2000) {
    lastDHTRead = millis();
    
    float h = dht.readHumidity();
    float t = dht.readTemperature();

    if (isnan(h) || isnan(t)) {
      Serial.println("DHT Error");
      bt.println("DHT Error");
    } else {
      // Send to Bluetooth (format: "temp;hum;")
      bt.print(t);
      bt.print(";");
      bt.print(h);
      bt.println(";");
      
      // Debug output to Serial Monitor
      Serial.print("Temp:");
      Serial.print(t);
      Serial.print("°C Hum:");
      Serial.print(h);
      Serial.println("%");
    }
  }

  // Part 2: LED Control (checks both Serial and Bluetooth)
  if (Serial.available() || bt.available()) {
    int input;
    
    // Read from whichever has data
    if (Serial.available()) {
      input = Serial.read();
    } else {
      input = bt.read();
    }
    
    // Process valid PWM values (0-255)
    if (input >= 0 && input <= 255) {
      // Set all LEDs to the same brightness
      for (int i = 0; i < numLeds; i++) {
        analogWrite(ledPins[i], input);
      }
      
      // Send confirmation
      Serial.print("LEDs:");
      Serial.println(input);
      bt.print("LEDs:");
      bt.println(input);
    }
  }
}